package com.xx.hbhconsumer.ui.order;

import android.app.Application;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.lifecycle.MutableLiveData;

import com.xx.hbhconsumer.data.http.requst.OrderRequest;
import com.xx.hbhconsumer.data.http.requst.PhoneRequest;
import com.xx.hbhconsumer.data.http.respons.ActivityCouponBean;
import com.xx.hbhconsumer.data.http.respons.ClaimedCoupon;
import com.xx.hbhconsumer.data.http.respons.Commodity;
import com.xx.hbhconsumer.data.http.respons.OrderBean;
import com.xx.hbhconsumer.ui.activity.ActivityViewModel;
import com.xx.hbhconsumer.ui.credit.CreditExchangeDialog;
import com.xx.hbhconsumer.ui.home.SignDialog;
import com.xx.xxviewlibrary.base.xxBaseDialog;

import java.util.ArrayList;
import java.util.List;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;

public class OrderDetailViewModel extends BaseViewModel<OrderRequest> {

    public MutableLiveData<OrderBean> orderBean = new  MutableLiveData<>(null);
    public MutableLiveData<ClaimedCoupon> claimedCoupon = new  MutableLiveData<>(null);

    private String orderId;
    public OrderDetailViewModel(@NonNull Application application) {
        super(application);
    }

    public OrderDetailViewModel(@NonNull Application application, OrderRequest model, String orderId) {
        super(application, model);
        this.orderId = orderId;
    }


    @Override
    public void onCreate() {
        super.onCreate();
    }

    @Override
    public void onStart() {
        super.onStart();
    }

    @Override
    public void onResume() {
        super.onResume();
        loadGoodsData(orderId);
    }

    public void loadGoodsData(String businessId) {
        model.getOrderDetail(businessId)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(OrderDetailViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<OrderBean>() {
                    @Override
                    public void onSuccess(OrderBean resultBean) {
                        orderBean.postValue(resultBean);
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                });
    }

    public void loadCoupon(View view) {
        model.getCouponAppList(orderId)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(OrderDetailViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<ClaimedCoupon>() {
                    @Override
                    public void onSuccess(ClaimedCoupon resultBean) {
                        showChooseCouponDialog(view, resultBean);
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                });
    }

    public void cancel(String businessId) {
        model.closeOrder(businessId)
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(OrderDetailViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<Boolean>() {
                    @Override
                    public void onSuccess(Boolean resultBean) {
                        ToastUtils.showShort(" 关闭成功");
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                });
    }

    public void chooseCoupon(View view) {
        loadCoupon(view);
    }

    public void receiveCoupon(View view) {
        showReceiveCouponDialog(view);
    }



    public void pay(View view) {
        showPayDialog(view);
    }

    private void showPayDialog(View view) {
        OrderPayDialog dialog=new OrderPayDialog(view.getContext(), 1);
        dialog.show();
    }

    private void showChooseCouponDialog(View view, ClaimedCoupon resultBean) {
        ChooseCouponDialog dialog = new ChooseCouponDialog(view.getContext(), resultBean);
        dialog.show();
    }

    private void showReceiveCouponDialog(View view) {
        ReceiveCouponDialog dialog = new ReceiveCouponDialog(view.getContext(), 1);
        dialog.show();
    }
}
