package com.xx.hbhconsumer.ui.register;

import static me.goldze.mvvmhabit.utils.Utils.Interceptor_TOKEN;

import android.app.Application;
import android.os.Bundle;
import android.text.TextUtils;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableField;

import com.xx.hbhconsumer.data.http.requst.LoginRequest;
import com.xx.hbhconsumer.data.http.requst.body.RegisterRequest;
import com.xx.hbhconsumer.data.http.respons.UserInfoBean;
import com.xx.hbhconsumer.data.local.LocalData;
import com.xx.hbhconsumer.ui.login.LoginActivity;
import com.xx.hbhconsumer.ui.main.MainActivity;
import com.xx.hbhconsumer.ui.privacyclause.PrivacyClauseActivity;
import com.xx.hbhconsumer.ui.pwd.ForgetPwdActivity;
import com.xx.hbhconsumer.ui.useragreement.UserAgreementActivity;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingAction;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;

public class RegisterViewModel extends BaseViewModel<RegisterRequest> {

    //用户名的绑定
    public ObservableField<String> phone = new ObservableField<>("");
    //密码的绑定
    public ObservableField<String> code = new ObservableField<>("");
    public ObservableField<String> password = new ObservableField<>("");
    public ObservableField<String> confirmPassword = new ObservableField<>("");

    public RegisterViewModel(@NonNull Application application, RegisterRequest model) {
        super(application, model);
    }

    public BindingCommand goPrivacyClause = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            startActivity(PrivacyClauseActivity.class);
        }

    });

    public BindingCommand goUserAgreement = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            startActivity(UserAgreementActivity.class);
        }

    });

    //跳转忘记密码
    public BindingCommand goLogin = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            startActivity(LoginActivity.class);
        }

    });

    public BindingCommand getVerificationCode = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            if (TextUtils.isEmpty(phone.get().toString())) {
                ToastUtils.showShort("请输手机号码！");

            } else {
                model.getCode(phone.get())
                        .compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
                        .doOnSubscribe(RegisterViewModel.this)
                        .doOnSubscribe(new Consumer<Disposable>() {
                            @Override
                            public void accept(Disposable disposable) throws Exception {
                                showDialog("正在请求...");
                            }
                        }).subscribe(new ApiDisposableObserver<String>() {
                            @Override
                            public void onSuccess(String resultBean) {
                                dismissDialog();
                                ToastUtils.showShort("发送成功！");
                            }

                            @Override
                            public void onError(String Error) {
                                dismissDialog();
                            }

                        });
            }
        }
    });

    //登陆
    public BindingCommand register = new BindingCommand(new BindingAction() {
        @Override
        public void call() {

            if (TextUtils.isEmpty(phone.get().toString())) {
                ToastUtils.showShort("请输入手机号码！");
            } else if (TextUtils.isEmpty(code.get().toString())) {
                ToastUtils.showShort("请输入验证码！");
            } else if (TextUtils.isEmpty(password.get().toString())) {
                ToastUtils.showShort("请输入密码！");
            } else if (TextUtils.isEmpty(confirmPassword.get().toString())) {
                ToastUtils.showShort("请输入确认密码！");
            } else if (!confirmPassword.get().equals(password.get())) {
                ToastUtils.showShort("密码与确认密码不一致！");
            } else {
                model.register(phone.get(), phone.get(), code.get())
                        .compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
                        .doOnSubscribe(RegisterViewModel.this)
                        .doOnSubscribe(new Consumer<Disposable>() {
                            @Override
                            public void accept(Disposable disposable) throws Exception {
                                showDialog("正在请求...");
                            }
                        }).subscribe(new ApiDisposableObserver<String>() {
                            @Override
                            public void onSuccess(String resultBean) {
                                dismissDialog();
                                startActivity(LoginActivity.class);
                            }
                            @Override
                            public void onError(String Error) {
                                dismissDialog();
                            }

                        });
            }
        }
    });



}


