package com.xx.hbhconsumer.ui.search;

import android.os.Bundle;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.fragment.app.Fragment;
import androidx.lifecycle.Observer;
import androidx.recyclerview.widget.GridLayoutManager;
import androidx.viewpager2.adapter.FragmentStateAdapter;
import androidx.viewpager2.widget.ViewPager2;

import com.google.android.flexbox.FlexDirection;
import com.google.android.flexbox.FlexWrap;
import com.google.android.flexbox.FlexboxLayoutManager;
import com.google.android.material.tabs.TabLayout;
import com.google.android.material.tabs.TabLayoutMediator;
import com.xx.hbhconsumer.R;
import com.xx.hbhconsumer.adapter.OrderAdapter;
import com.xx.hbhconsumer.adapter.SearchGoodsAdapter;
import com.xx.hbhconsumer.adapter.SearchHistoryAdapter;
import com.xx.hbhconsumer.adapter.SearchShopAdapter;
import com.xx.hbhconsumer.data.http.requst.LoginRequest;
import com.xx.hbhconsumer.data.http.requst.SearchRequest;
import com.xx.hbhconsumer.data.http.respons.OrderBean;
import com.xx.hbhconsumer.data.http.respons.SearchGoodsBean;
import com.xx.hbhconsumer.data.http.respons.SearchShopBean;
import com.xx.hbhconsumer.databinding.ActivitySearchBinding;
import com.xx.hbhconsumer.ui.order.OrderListFragment;
import com.xx.hbhconsumer.ui.recruit.RecruitListViewModel;

import java.util.ArrayList;
import java.util.List;

import me.goldze.mvvmhabit.base.BaseActivity;
import me.tatarka.bindingcollectionadapter2.BR;

public class SearchActivity extends BaseActivity<ActivitySearchBinding, SearchViewModel> {

    @Override
    public int initContentView(Bundle savedInstanceState) {
        return R.layout.activity_search;
    }

    @Override
    public int initVariableId() {
        return BR.searchViewModel;
    }

    @Override
    public void initData() {
        super.initData();

        List<OrderBean> orderBeanList = new ArrayList<>();

        viewModel.showPriceFlag.observe(this, new Observer<Boolean>() {
            @Override
            public void onChanged(Boolean showPriceFlag) {
                if (showPriceFlag) {
                    binding.rlSearchArea.setVisibility(View.VISIBLE);
                    binding.llPriceSearch.setVisibility(View.VISIBLE);
                } else {
                    binding.rlSearchArea.setVisibility(View.GONE);
                    binding.llPriceSearch.setVisibility(View.GONE);
                }
            }
        });

        viewModel.showSortFlag.observe(this, new Observer<Boolean>() {
            @Override
            public void onChanged(Boolean showPriceFlag) {
                if (showPriceFlag) {
                    binding.rlSearchArea.setVisibility(View.VISIBLE);
                    binding.llSortSelect.setVisibility(View.VISIBLE);
                } else {
                    binding.rlSearchArea.setVisibility(View.GONE);
                    binding.llSortSelect.setVisibility(View.GONE);
                }
            }
        });

        viewModel.searchType.observe(this, new Observer<Integer>() {
            @Override
            public void onChanged(Integer searchType) {
                if (searchType == 0) {
                    binding.rvSearchHistory.setVisibility(View.VISIBLE);
                    binding.rlSearchHistoryBar.setVisibility(View.VISIBLE);
                    binding.rvSearchResult.setVisibility(View.GONE);
                    binding.rlSearchTab.setVisibility(View.GONE);
                    binding.rlSearchArea.setVisibility(View.GONE);
                    binding.rlSearchBar.setVisibility(View.GONE);

                } else {
                    binding.rvSearchHistory.setVisibility(View.GONE);
                    binding.rlSearchHistoryBar.setVisibility(View.GONE);
                    binding.rvSearchResult.setVisibility(View.VISIBLE);
                    binding.rlSearchTab.setVisibility(View.VISIBLE);
                    binding.rlSearchBar.setVisibility(View.VISIBLE);
                }
            }
        });

        viewModel.searchGoodsBeanList.observe(this, new Observer<List<SearchGoodsBean>>() {
            @Override
            public void onChanged(List<SearchGoodsBean> goodsBeanList) {
                //获取适配器上下文
                SearchGoodsAdapter searchGoodsAdapter = new SearchGoodsAdapter(SearchActivity.this);
                //获取适配器上下文
                GridLayoutManager manager = new GridLayoutManager(SearchActivity.this,2);
                binding.rvSearchResult.setLayoutManager(manager);
                //把adapterset进去
                binding.rvSearchResult.setAdapter(searchGoodsAdapter);
                searchGoodsAdapter.mList = goodsBeanList;
                searchGoodsAdapter.setOnItemClick((position, data) -> viewModel.goGoodsDetail(position));

            }
        });

        viewModel.searchShopBeanList.observe(this, new Observer<List<SearchShopBean>>() {
            @Override
            public void onChanged(List<SearchShopBean> searchShopBeanList) {
                //获取适配器上下文
                SearchShopAdapter orderListAdapter = new SearchShopAdapter(SearchActivity.this);

                //把adapterset进去
                binding.rvSearchResult.setAdapter(orderListAdapter);
                orderListAdapter.mList = searchShopBeanList;

                orderListAdapter.setOnItemClick((position, data) -> viewModel.goShopDetail(data.getBusinessId()));

            }
        });


        FlexboxLayoutManager manager = new FlexboxLayoutManager(this, FlexDirection.ROW, FlexWrap.WRAP);
        binding.rvSearchHistory.setLayoutManager(manager);
        //获取适配器上下文
        SearchHistoryAdapter orderListAdapter = new SearchHistoryAdapter(this);
        //把adapterset进去
        binding.rvSearchHistory.setAdapter(orderListAdapter);
        orderListAdapter.mList = orderBeanList;
        /*切换状态Tab*/
        binding.tabLayout.addOnTabSelectedListener(new TabLayout.OnTabSelectedListener() {
            @Override
            public void onTabSelected(TabLayout.Tab tab) {
                switch (tab.getPosition()) {
                    case 0:
                        viewModel.searchType.postValue(1);
                        viewModel.search();
                        break;
                    case 1:
                        viewModel.searchType.postValue(2);
                        viewModel.search();
                        break;
                }
            }

            @Override
            public void onTabUnselected(TabLayout.Tab tab) {
            }

            @Override
            public void onTabReselected(TabLayout.Tab tab) {
            }
        });
    }

    @Override
    public SearchViewModel initViewModel() {
        SearchRequest model = new SearchRequest();
        return new SearchViewModel(getApplication(), model);
    }
}
