package com.xx.hbhconsumer.ui.search;

import android.app.Application;
import android.os.Bundle;
import android.util.Log;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableField;
import androidx.lifecycle.MutableLiveData;

import com.xx.hbhconsumer.data.http.requst.SearchRequest;
import com.xx.hbhconsumer.data.http.respons.SearchGoodsBean;
import com.xx.hbhconsumer.data.http.respons.SearchShopBean;
import com.xx.hbhconsumer.ui.shop.ShopDetailActivity;

import java.util.ArrayList;
import java.util.List;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.http.ApiDisposablePageObserver;
import me.goldze.mvvmhabit.utils.RxUtils;

public class SearchViewModel extends BaseViewModel<SearchRequest> {
    private static final String TAG = "SearchViewModel";
    public MutableLiveData<Integer> searchType = new  MutableLiveData<>(0);
    public MutableLiveData<List<SearchGoodsBean>> searchGoodsBeanList = new  MutableLiveData<>(new ArrayList<>());
    public MutableLiveData<List<SearchShopBean>> searchShopBeanList = new  MutableLiveData<>(new ArrayList<>());
    public ObservableField<String> searchWord = new ObservableField<>("");


    public MutableLiveData<Boolean> showSortFlag = new  MutableLiveData<>(false);
    public MutableLiveData<Boolean> showPriceFlag = new  MutableLiveData<>(false);

    public SearchViewModel(@NonNull Application application) {
        super(application);
    }

    public SearchViewModel(@NonNull Application application, SearchRequest model) {
        super(application, model);
    }

    public void goGoodsDetail(int p) {

    }

    public void goShopDetail(String merchantId) {
        Bundle bundle = new Bundle();
        bundle.putString("merchantId", merchantId);
        startActivity(ShopDetailActivity.class, bundle);
    }

    public void search() {
        if (searchType.getValue() == 0) {
            searchType.postValue(1);
        }
        if (searchType.getValue() == 1) {
            searchGoods();
        } else if (searchType.getValue() == 2) {
            searchShop();
        }
    }

    private void searchGoods() {
        model.searchGoods(searchWord.get())
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(SearchViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposablePageObserver<SearchGoodsBean>() {
                    @Override
                    public void onSuccess(List<SearchGoodsBean> resultBean) {
                        searchGoodsBeanList.postValue(resultBean);
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                    @Override
                    public void getTotal(int total) {

                    }


                });
    }

    private void searchShop() {
        model.searchShop(searchWord.get())
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(SearchViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposablePageObserver<SearchShopBean>() {
                    @Override
                    public void onSuccess(List<SearchShopBean> resultBean) {
                        searchShopBeanList.postValue(resultBean);
                    }
                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }
                    @Override
                    public void getTotal(int total) {

                    }


                });
    }

    public BindingCommand search = new BindingCommand(() -> search());


    public void sort(View view) {
        Log.i(TAG, ": sort");
        showSortFlag.postValue(!showSortFlag.getValue());
    }
    public void price(View view) {
        Log.i(TAG, ": price");
        showPriceFlag.postValue(!showPriceFlag.getValue());
    }

}
