package com.xx.hbhconsumer.ui.shop;

import android.app.Application;

import androidx.annotation.NonNull;
import androidx.lifecycle.MutableLiveData;

import com.xx.hbhconsumer.data.http.requst.PhoneRequest;
import com.xx.hbhconsumer.data.http.requst.ShopRequest;
import com.xx.hbhconsumer.data.http.respons.CollectionBean;
import com.xx.hbhconsumer.data.http.respons.ShopGoodsBean;
import com.xx.hbhconsumer.ui.category.CategoryActivity;

import java.util.ArrayList;
import java.util.List;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingAction;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.http.ApiDisposablePageObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.StringUtils;

public class ShopSearchViewModel extends BaseViewModel<ShopRequest> {

    private String categoryId;
    private List<String> categoryIdList;
    public MutableLiveData<String> searchWord = new MutableLiveData<>("");
    public MutableLiveData<String> merchantId = new MutableLiveData<>("");
    public MutableLiveData<List<ShopGoodsBean>> shopGoodsBeanList = new  MutableLiveData<>(new ArrayList<>());

    public MutableLiveData<Integer> searchState = new  MutableLiveData<>(0);

    public ShopSearchViewModel(@NonNull Application application) {
        super(application);
    }

    public ShopSearchViewModel(@NonNull Application application, ShopRequest model, String categoryId) {
        super(application, model);
        this.categoryId = categoryId;
        categoryIdList = new ArrayList<>();
        if (!StringUtils.isEmpty(categoryId)) {
            categoryIdList.add(categoryId);
        }
    }

    @Override
    public void onCreate() {
        super.onCreate();
    }

    @Override
    public void onStart() {
        super.onStart();
    }

    @Override
    public void onResume() {
        super.onResume();
        loadShopGoodsList();
    }

    private void loadShopGoodsList() {
        model.getShopGoodsList(categoryIdList, merchantId.getValue(), searchWord.getValue())
                .compose(RxUtils.schedulersTransformer()) //线程调度
                .doOnSubscribe(ShopSearchViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposablePageObserver<ShopGoodsBean>() {
                    @Override
                    public void onSuccess(List<ShopGoodsBean> resultBean) {
                        shopGoodsBeanList.postValue(resultBean);
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }

                    @Override
                    public void getTotal(int total) {

                    }

                });
    }

    public BindingCommand search = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            searchState.postValue(1);
        }

    });

    public BindingCommand goCategory = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            startActivity(CategoryActivity.class);
        }

    });

    public void goShopGoodsDetail(int position) {
        startActivity(ShopGoodsDetailActivity.class);
    }
}
